==> owncloud_7.0.4+dfsg.orig.tar.bz2: owncloud/core/l10n/en_GB.php <==
<?php
$TRANSLATIONS = array(
"Expiration date is in the past." => "Expiration date is in the past.",
"Couldn't send mail to following users: %s " => "Couldn't send mail to following users: %s ",
"Turned on maintenance mode" => "Turned on maintenance mode",
"Turned off maintenance mode" => "Turned off maintenance mode",
"Updated database" => "Updated database",
"Checked database schema update" => "Checked database schema update",
"Disabled incompatible apps: %s" => "Disabled incompatible apps: %s",
"No image or file provided" => "No image or file provided",
"Unknown filetype" => "Unknown filetype",
"Invalid image" => "Invalid image",
"No temporary profile picture available, try again" => "No temporary profile picture available, try again",
"No crop data provided" => "No crop data provided",
"Sunday" => "Sunday",
"Monday" => "Monday",
"Tuesday" => "Tuesday",
"Wednesday" => "Wednesday",
"Thursday" => "Thursday",
"Friday" => "Friday",
"Saturday" => "Saturday",
"January" => "January",
"February" => "February",
"March" => "March",
"April" => "April",
"May" => "May",
"June" => "June",
"July" => "July",
"August" => "August",
"September" => "September",
"October" => "October",
"November" => "November",
"December" => "December",
"Settings" => "Settings",
"File" => "File",
"Folder" => "Folder",
"Image" => "Image",
"Audio" => "Audio",
"Saving..." => "Saving...",
"seconds ago" => "seconds ago",
"_%n minute ago_::_%n minutes ago_" => array("%n minute ago","%n minutes ago"),
"_%n hour ago_::_%n hours ago_" => array("%n hour ago","%n hours ago"),
"today" => "today",
"yesterday" => "yesterday",
"_%n day ago_::_%n days ago_" => array("%n day ago","%n days ago"),
"last month" => "last month",
"_%n month ago_::_%n months ago_" => array("%n month ago","%n months ago"),
"last year" => "last year",
"years ago" => "years ago",
"Couldn't send reset email. Please contact your administrator." => "Couldn't send reset email. Please contact your administrator.",
"The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." => "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator.",
"Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" => "Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?",
"I know what I'm doing" => "I know what I'm doing",
"Reset password" => "Reset password",
"Password can not be changed. Please contact your administrator." => "Password can not be changed. Please contact your administrator.",
"Yes" => "Yes",
"No" => "No",
"Choose" => "Choose",
"Error loading file picker template: {error}" => "Error loading file picker template: {error}",
"Ok" => "OK",
"Error loading message template: {error}" => "Error loading message template: {error}",
"_{count} file conflict_::_{count} file conflicts_" => array("{count} file conflict","{count} file conflicts"),
"One file conflict" => "One file conflict",
"New Files" => "New Files",
"Already existing files" => "Already existing files",
"Which files do you want to keep?" => "Which files do you wish to keep?",
"If you select both versions, the copied file will have a number added to its name." => "If you select both versions, the copied file will have a number added to its name.",
"Cancel" => "Cancel",
"Continue" => "Continue",
"(all selected)" => "(all selected)",
"({count} selected)" => "({count} selected)",
"Error loading file exists template" => "Error loading file exists template",
"Very weak password" => "Very weak password",
"Weak password" => "Weak password",
"So-so password" => "So-so password",
"Good password" => "Good password",
"Strong password" => "Strong password",
"Shared" => "Shared",
"Shared by {owner}" => "Shared by {owner}",
"Shared with {recipients}" => "Shared with {recipients}",
"Share" => "Share",
"Error" => "Error",
"Error while sharing" => "Error whilst sharing",
"Error while unsharing" => "Error whilst unsharing",
"Error while changing permissions" => "Error whilst changing permissions",
"Shared with you and the group {group} by {owner}" => "Shared with you and the group {group} by {owner}",
"Shared with you by {owner}" => "Shared with you by {owner}",
"Share with user or group …" => "Share with user or group …",
"Share link" => "Share link",
"The public link will expire no later than {days} days after it is created" => "The public link will expire no later than {days} days after it is created",
"By default the public link will expire after {days} days" => "By default the public link will expire after {days} days",
"Password protect" => "Password protect",
"Choose a password for the public link" => "Choose a password for the public link",
"Allow Public Upload" => "Allow Public Upload",
"Email link to person" => "Email link to person",
"Send" => "Send",
"Set expiration date" => "Set expiration date",
"Expiration date" => "Expiration date",
"Share via email:" => "Share via email:",
"No people found" => "No people found",
"group" => "group",
"Resharing is not allowed" => "Resharing is not allowed",
"Shared in {item} with {user}" => "Shared in {item} with {user}",
"Unshare" => "Unshare",
"notify by email" => "notify by email",
"can share" => "can share",
"can edit" => "can edit",
"access control" => "access control",
"create" => "create",
"update" => "update",
"delete" => "delete",
"Password protected" => "Password protected",
"Error unsetting expiration date" => "Error unsetting expiration date",
"Error setting expiration date" => "Error setting expiration date",
"Sending ..." => "Sending ...",
"Email sent" => "Email sent",
"Warning" => "Warning",
"The object type is not specified." => "The object type is not specified.",
"Enter new" => "Enter new",
"Delete" => "Delete",
"Add" => "Add",
"Edit tags" => "Edit tags",
"Error loading dialog template: {error}" => "Error loading dialog template: {error}",
"No tags selected for deletion." => "No tags selected for deletion.",
"Updating {productName} to version {version}, this may take a while." => "Updating {productName} to version {version}, this may take a while.",
"Please reload the page." => "Please reload the page.",
"The update was unsuccessful." => "The update was unsuccessful.",
"The update was successful. Redirecting you to ownCloud now." => "The update was successful. Redirecting you to ownCloud now.",
"Couldn't reset password because the token is invalid" => "Couldn't reset password because the token is invalid",
"Couldn't send reset email. Please make sure your username is correct." => "Couldn't send reset email. Please make sure your username is correct.",
"Couldn't send reset email because there is no email address for this username. Please contact your administrator." => "Couldn't send reset email because there is no email address for this username. Please contact your administrator.",
"%s password reset" => "%s password reset",
"Use the following link to reset your password: {link}" => "Use the following link to reset your password: {link}",
"You will receive a link to reset your password via Email." => "You will receive a link to reset your password via email.",
"Username" => "Username",
"Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" => "Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?",
"Yes, I really want to reset my password now" => "Yes, I really want to reset my password now",
"Reset" => "Reset",
"New password" => "New password",
"New Password" => "New Password",
"Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " => "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! ",
"For the best results, please consider using a GNU/Linux server instead." => "For the best results, please consider using a GNU/Linux server instead.",
"Personal" => "Personal",
"Users" => "Users",
"Apps" => "Apps",
"Admin" => "Admin",
"Help" => "Help",
"Error loading tags" => "Error loading tags",
"Tag already exists" => "Tag already exists",
"Error deleting tag(s)" => "Error deleting tag(s)",
"Error tagging" => "Error tagging",
"Error untagging" => "Error untagging",
"Error favoriting" => "Error favouriting",
"Error unfavoriting" => "Error unfavouriting",
"Access forbidden" => "Access denied",
"Cloud not found" => "Cloud not found",
"Hey there,\n\njust letting you know that %s shared %s with you.\nView it: %s\n\n" => "Hey there,\n\njust letting you know that %s shared %s with you.\nView it: %s\n\n",
"The share will expire on %s." => "The share will expire on %s.",
"Cheers!" => "Cheers!",
"Security Warning" => "Security Warning",
"Your PHP version is vulnerable to the NULL Byte attack (CVE-2006-7243)" => "Your PHP version is vulnerable to the NULL Byte attack (CVE-2006-7243)",
"Please update your PHP installation to use %s securely." => "Please update your PHP installation to use %s securely.",
"No secure random number generator is available, please enable the PHP OpenSSL extension." => "No secure random number generator is available, please enable the PHP OpenSSL extension.",
"Without a secure random number generator an attacker may be able to predict password reset tokens and take over your account." => "Without a secure random number generator an attacker may be able to predict password reset tokens and take over your account.",
"Your data directory and files are probably accessible from the internet because the .htaccess file does not work." => "Your data directory and files are probably accessible from the internet because the .htaccess file does not work.",
"For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\">documentation</a>." => "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\">documentation</a>.",
"Create an <strong>admin account</strong>" => "Create an <strong>admin account</strong>",
"Password" => "Password",
"Storage & database" => "Storage & database",
"Data folder" => "Data folder",
"Configure the database" => "Configure the database",
"Only %s is available." => "Only %s is available.",
"Database user" => "Database user",
"Database password" => "Database password",
"Database name" => "Database name",
"Database tablespace" => "Database tablespace",
"Database host" => "Database host",
"SQLite will be used as database. For larger installations we recommend to change this." => "SQLite will be used as database. For larger installations we recommend changing this.",
"Finish setup" => "Finish setup",
"Finishing …" => "Finishing …",
"This application requires JavaScript to be enabled for correct operation.  Please <a href=\"http://enable-javascript.com/\" target=\"_blank\">enable JavaScript</a> and re-load this interface." => "This application requires JavaScript to be enabled for correct operation.  Please <a href=\"http://enable-javascript.com/\" target=\"_blank\">enable JavaScript</a> and re-load this interface.",
"%s is available. Get more information on how to update." => "%s is available. Get more information on how to update.",
"Log out" => "Log out",
"Automatic logon rejected!" => "Automatic logon rejected!",
"If you did not change your password recently, your account may be compromised!" => "If you did not change your password recently, your account may be compromised!",
"Please change your password to secure your account again." => "Please change your password to secure your account again.",
"Server side authentication failed!" => "Server side authentication failed!",
"Please contact your administrator." => "Please contact your administrator.",
"Forgot your password? Reset it!" => "Forgot your password? Reset it!",
"remember" => "remember",
"Log in" => "Log in",
"Alternative Logins" => "Alternative Logins",
"Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" => "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>",
"This ownCloud instance is currently in single user mode." => "This ownCloud instance is currently in single user mode.",
"This means only administrators can use the instance." => "This means only administrators can use the instance.",
"Contact your system administrator if this message persists or appeared unexpectedly." => "Contact your system administrator if this message persists or appeared unexpectedly.",
"Thank you for your patience." => "Thank you for your patience.",
"%s will be updated to version %s." => "%s will be updated to version %s.",
"The following apps will be disabled:" => "The following apps will be disabled:",
"The theme %s has been disabled." => "The theme %s has been disabled.",
"Please make sure that the database, the config folder and the data folder have been backed up before proceeding." => "Please make sure that the database, the config folder and the data folder have been backed up before proceeding.",
"Start update" => "Start update",
"This ownCloud instance is currently being updated, which may take a while." => "This ownCloud instance is currently being updated, which may take a while.",
"Please reload this page after a short time to continue using ownCloud." => "Please reload this page after a short time to continue using ownCloud."
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";

==> owncloud_7.0.13~dfsg.orig.tar.bz2: owncloud/core/l10n/en_GB.php <==
<?php
$TRANSLATIONS = array(
"Expiration date is in the past." => "Expiration date is in the past.",
"Couldn't send mail to following users: %s " => "Couldn't send mail to following users: %s ",
"Turned on maintenance mode" => "Turned on maintenance mode",
"Turned off maintenance mode" => "Turned off maintenance mode",
"Updated database" => "Updated database",
"Checked database schema update" => "Checked database schema update",
"Disabled incompatible apps: %s" => "Disabled incompatible apps: %s",
"No image or file provided" => "No image or file provided",
"Unknown filetype" => "Unknown filetype",
"Invalid image" => "Invalid image",
"No temporary profile picture available, try again" => "No temporary profile picture available, try again",
"No crop data provided" => "No crop data provided",
"Sunday" => "Sunday",
"Monday" => "Monday",
"Tuesday" => "Tuesday",
"Wednesday" => "Wednesday",
"Thursday" => "Thursday",
"Friday" => "Friday",
"Saturday" => "Saturday",
"January" => "January",
"February" => "February",
"March" => "March",
"April" => "April",
"May" => "May",
"June" => "June",
"July" => "July",
"August" => "August",
"September" => "September",
"October" => "October",
"November" => "November",
"December" => "December",
"Settings" => "Settings",
"File" => "File",
"Folder" => "Folder",
"Image" => "Image",
"Audio" => "Audio",
"Saving..." => "Saving...",
"seconds ago" => "seconds ago",
"_%n minute ago_::_%n minutes ago_" => array("%n minute ago","%n minutes ago"),
"_%n hour ago_::_%n hours ago_" => array("%n hour ago","%n hours ago"),
"today" => "today",
"yesterday" => "yesterday",
"_%n day ago_::_%n days ago_" => array("%n day ago","%n days ago"),
"last month" => "last month",
"_%n month ago_::_%n months ago_" => array("%n month ago","%n months ago"),
"last year" => "last year",
"years ago" => "years ago",
"Couldn't send reset email. Please contact your administrator." => "Couldn't send reset email. Please contact your administrator.",
"The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." => "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator.",
"Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" => "Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?",
"I know what I'm doing" => "I know what I'm doing",
"Reset password" => "Reset password",
"Password can not be changed. Please contact your administrator." => "Password can not be changed. Please contact your administrator.",
"Yes" => "Yes",
"No" => "No",
"Choose" => "Choose",
"Error loading file picker template: {error}" => "Error loading file picker template: {error}",
"Ok" => "OK",
"Error loading message template: {error}" => "Error loading message template: {error}",
"_{count} file conflict_::_{count} file conflicts_" => array("{count} file conflict","{count} file conflicts"),
"One file conflict" => "One file conflict",
"New Files" => "New Files",
"Already existing files" => "Already existing files",
"Which files do you want to keep?" => "Which files do you wish to keep?",
"If you select both versions, the copied file will have a number added to its name." => "If you select both versions, the copied file will have a number added to its name.",
"Cancel" => "Cancel",
"Continue" => "Continue",
"(all selected)" => "(all selected)",
"({count} selected)" => "({count} selected)",
"Error loading file exists template" => "Error loading file exists template",
"Very weak password" => "Very weak password",
"Weak password" => "Weak password",
"So-so password" => "So-so password",
"Good password" => "Good password",
"Strong password" => "Strong password",
"Shared" => "Shared",
"Shared by {owner}" => "Shared by {owner}",
"Shared with {recipients}" => "Shared with {recipients}",
"Share" => "Share",
"Error" => "Error",
"Error while sharing" => "Error whilst sharing",
"Error while unsharing" => "Error whilst unsharing",
"Error while changing permissions" => "Error whilst changing permissions",
"Shared with you and the group {group} by {owner}" => "Shared with you and the group {group} by {owner}",
"Shared with you by {owner}" => "Shared with you by {owner}",
"Share with user or group …" => "Share with user or group …",
"Share link" => "Share link",
"The public link will expire no later than {days} days after it is created" => "The public link will expire no later than {days} days after it is created",
"By default the public link will expire after {days} days" => "By default the public link will expire after {days} days",
"Password protect" => "Password protect",
"Choose a password for the public link" => "Choose a password for the public link",
"Allow Public Upload" => "Allow Public Upload",
"Email link to person" => "Email link to person",
"Send" => "Send",
"Set expiration date" => "Set expiration date",
"Expiration date" => "Expiration date",
"Share via email:" => "Share via email:",
"No people found" => "No people found",
"group" => "group",
"Resharing is not allowed" => "Resharing is not allowed",
"Shared in {item} with {user}" => "Shared in {item} with {user}",
"Unshare" => "Unshare",
"notify by email" => "notify by email",
"can share" => "can share",
"can edit" => "can edit",
"access control" => "access control",
"create" => "create",
"update" => "update",
"delete" => "delete",
"Password protected" => "Password protected",
"Error unsetting expiration date" => "Error unsetting expiration date",
"Error setting expiration date" => "Error setting expiration date",
"Sending ..." => "Sending ...",
"Email sent" => "Email sent",
"Warning" => "Warning",
"The object type is not specified." => "The object type is not specified.",
"Enter new" => "Enter new",
"Delete" => "Delete",
"Add" => "Add",
"Edit tags" => "Edit tags",
"Error loading dialog template: {error}" => "Error loading dialog template: {error}",
"No tags selected for deletion." => "No tags selected for deletion.",
"Updating {productName} to version {version}, this may take a while." => "Updating {productName} to version {version}, this may take a while.",
"Please reload the page." => "Please reload the page.",
"The update was unsuccessful." => "The update was unsuccessful.",
"The update was successful. Redirecting you to ownCloud now." => "The update was successful. Redirecting you to ownCloud now.",
"Couldn't reset password because the token is invalid" => "Couldn't reset password because the token is invalid",
"Couldn't send reset email. Please make sure your username is correct." => "Couldn't send reset email. Please make sure your username is correct.",
"Couldn't send reset email because there is no email address for this username. Please contact your administrator." => "Couldn't send reset email because there is no email address for this username. Please contact your administrator.",
"%s password reset" => "%s password reset",
"Use the following link to reset your password: {link}" => "Use the following link to reset your password: {link}",
"You will receive a link to reset your password via Email." => "You will receive a link to reset your password via email.",
"Username" => "Username",
"Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" => "Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?",
"Yes, I really want to reset my password now" => "Yes, I really want to reset my password now",
"Reset" => "Reset",
"New password" => "New password",
"New Password" => "New Password",
"Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " => "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! ",
"For the best results, please consider using a GNU/Linux server instead." => "For the best results, please consider using a GNU/Linux server instead.",
"Personal" => "Personal",
"Users" => "Users",
"Apps" => "Apps",
"Admin" => "Admin",
"Help" => "Help",
"Error loading tags" => "Error loading tags",
"Tag already exists" => "Tag already exists",
"Error deleting tag(s)" => "Error deleting tag(s)",
"Error tagging" => "Error tagging",
"Error untagging" => "Error untagging",
"Error favoriting" => "Error favouriting",
"Error unfavoriting" => "Error unfavouriting",
"Access forbidden" => "Access denied",
"Cloud not found" => "Cloud not found",
"Hey there,\n\njust letting you know that %s shared %s with you.\nView it: %s\n\n" => "Hey there,\n\njust letting you know that %s shared %s with you.\nView it: %s\n\n",
"The share will expire on %s." => "The share will expire on %s.",
"Cheers!" => "Cheers!",
"Security Warning" => "Security Warning",
"Your PHP version is vulnerable to the NULL Byte attack (CVE-2006-7243)" => "Your PHP version is vulnerable to the NULL Byte attack (CVE-2006-7243)",
"Please update your PHP installation to use %s securely." => "Please update your PHP installation to use %s securely.",
"No secure random number generator is available, please enable the PHP OpenSSL extension." => "No secure random number generator is available, please enable the PHP OpenSSL extension.",
"Without a secure random number generator an attacker may be able to predict password reset tokens and take over your account." => "Without a secure random number generator an attacker may be able to predict password reset tokens and take over your account.",
"Your data directory and files are probably accessible from the internet because the .htaccess file does not work." => "Your data directory and files are probably accessible from the internet because the .htaccess file does not work.",
"For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\">documentation</a>." => "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\">documentation</a>.",
"Create an <strong>admin account</strong>" => "Create an <strong>admin account</strong>",
"Password" => "Password",
"Storage & database" => "Storage & database",
"Data folder" => "Data folder",
"Configure the database" => "Configure the database",
"Only %s is available." => "Only %s is available.",
"Database user" => "Database user",
"Database password" => "Database password",
"Database name" => "Database name",
"Database tablespace" => "Database tablespace",
"Database host" => "Database host",
"SQLite will be used as database. For larger installations we recommend to change this." => "SQLite will be used as database. For larger installations we recommend changing this.",
"Finish setup" => "Finish setup",
"Finishing …" => "Finishing …",
"This application requires JavaScript to be enabled for correct operation.  Please <a href=\"http://enable-javascript.com/\" target=\"_blank\">enable JavaScript</a> and re-load this interface." => "This application requires JavaScript to be enabled for correct operation.  Please <a href=\"http://enable-javascript.com/\" target=\"_blank\">enable JavaScript</a> and re-load this interface.",
"%s is available. Get more information on how to update." => "%s is available. Get more information on how to update.",
"Log out" => "Log out",
"Automatic logon rejected!" => "Automatic logon rejected!",
"If you did not change your password recently, your account may be compromised!" => "If you did not change your password recently, your account may be compromised!",
"Please change your password to secure your account again." => "Please change your password to secure your account again.",
"Server side authentication failed!" => "Server side authentication failed!",
"Please contact your administrator." => "Please contact your administrator.",
"Forgot your password? Reset it!" => "Forgot your password? Reset it!",
"remember" => "remember",
"Log in" => "Log in",
"Alternative Logins" => "Alternative Logins",
"Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" => "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>",
"This ownCloud instance is currently in single user mode." => "This ownCloud instance is currently in single user mode.",
"This means only administrators can use the instance." => "This means only administrators can use the instance.",
"Contact your system administrator if this message persists or appeared unexpectedly." => "Contact your system administrator if this message persists or appeared unexpectedly.",
"Thank you for your patience." => "Thank you for your patience.",
"%s will be updated to version %s." => "%s will be updated to version %s.",
"The following apps will be disabled:" => "The following apps will be disabled:",
"The theme %s has been disabled." => "The theme %s has been disabled.",
"Please make sure that the database, the config folder and the data folder have been backed up before proceeding." => "Please make sure that the database, the config folder and the data folder have been backed up before proceeding.",
"Start update" => "Start update",
"This ownCloud instance is currently being updated, which may take a while." => "This ownCloud instance is currently being updated, which may take a while.",
"Please reload this page after a short time to continue using ownCloud." => "Please reload this page after a short time to continue using ownCloud.",
"To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" => "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:",
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
